@@ -28,7 +28,7 @@ def get_address_after_token(output, token, return_first=false)
 
   String(output).scan(/#{token}\s?((?>[0-9,a-f,A-F]*\:{1,2})+[0-9,a-f,A-F]{0,4})/).each do |match|
     match = match.first
-    unless match =~ /fe80.*/ or match == "::1"
+    unless match =~ /^fe80.*/ or match == "::1"
       ip = match
       break if return_first
     end
@@ -37,11 +37,12 @@ def get_address_after_token(output, token, return_first=false)
   ip
 end
 
+
 Facter.add(:ipaddress6) do
   confine :kernel => :linux
   setcode do
-    output = Facter::Util::IP.exec_ifconfig(["2>/dev/null"])
-    get_address_after_token(output, 'inet6(?: addr:)?')
+    iface = Facter::Util::IP.linux_default_iface
+    Facter.value("ipaddress6_#{iface}")
   end
 end
 
