@@ -4,10 +4,6 @@ require 'spec_helper'
 require 'facter/util/ip'
 
 describe "ipaddress fact" do
-  before do
-    Facter.collection.internal_loader.load(:ipaddress)
-  end
-
   context 'using `ifconfig`' do
     before :each do
       Facter.fact(:hostname).stubs(:value)
@@ -18,25 +14,29 @@ describe "ipaddress fact" do
         Facter.fact(:kernel).stubs(:value).returns("Linux")
       end
 
+      after :each do
+        Facter.collection.flush
+      end
+
       def expect_ifconfig_parse(address, fixture)
-        Facter::Util::IP.stubs(:exec_ifconfig).returns(my_fixture_read(fixture))
+        Facter::Util::IP.stubs(:exec_ifconfig).returns(my_fixture_read("ifconfig_#{fixture}"))
+        routes = my_fixture_read("net_route_#{fixture}")
+        Facter::Util::IP.stubs(:read_proc_net_route).returns(routes)
+        Facter.collection.internal_loader.load(:interfaces)
+        Facter.collection.internal_loader.load(:ipaddress)
         Facter.fact(:ipaddress).value.should == address
       end
 
       it "parses correctly on Ubuntu 12.04" do
-        expect_ifconfig_parse "10.87.80.110", "ifconfig_ubuntu_1204.txt"
+        expect_ifconfig_parse "10.87.80.110", "ubuntu_1204.txt"
       end
 
       it "parses correctly on Fedora 17" do
-        expect_ifconfig_parse "131.252.209.153", "ifconfig_net_tools_1.60.txt"
-      end
-
-      it "parses a real address over multiple loopback addresses" do
-        expect_ifconfig_parse "10.0.222.20", "ifconfig_multiple_127_addresses.txt"
+        expect_ifconfig_parse "131.252.209.153", "net_tools_1.60.txt"
       end
 
       it "parses nothing with a non-english locale" do
-        expect_ifconfig_parse nil, "ifconfig_non_english_locale.txt"
+        expect_ifconfig_parse nil, "non_english_locale.txt"
       end
     end
   end
@@ -60,7 +60,7 @@ describe "ipaddress fact" do
     context "when you have no active network adapter" do
       it "should return nil if there are no active (or any) network adapters" do
         Facter::Util::WMI.expects(:execquery).with(Facter::Util::IP::Windows::WMI_IP_INFO_QUERY).returns([])
-        Facter::Core::Execution.stubs(:exec)
+        Facter::Core::Execution.stubs(:execute)
 
         Facter.value(:ipaddress).should == nil
       end
